@@ -1,5 +1,5 @@
 
-renv_report_user_cancel <- function() {
+renv_report_user_cancel <- function(reason = NULL) {
   message("* Operation canceled.")
   renv_snapshot_auto_suppress_next()
 }
